<?php
/**
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade Magento to newer
 * versions in the future. If you wish to customize Magento for your
 * needs please refer to http://www.magentocommerce.com for more information.
 *
 * @copyright   Copyright (c) 2014 X.commerce, Inc. (http://www.magentocommerce.com)
 * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

namespace Mtf\Util;

/**
 * Class XmlConverter
 */
class XmlConverter
{
    /**
     * Convert SimpleXMLElement into string
     *
     * @param \SimpleXMLElement $element
     * @return array|string
     */
    public function convert(\SimpleXMLElement $element)
    {
        $result = [];

        foreach ($element->attributes() as $attributeName => $attribute) {
            if ($attribute) {
                $result[$attributeName] = (string)$attribute;
            }
        }

        // add children values
        if ($this->hasChildren($element)) {
            foreach ($element->children() as $childName => $child) {
                $result[$childName] = $this->convert($child);
            }
        } else {
            if (empty($result)) {
                // return as string, if nothing was found
                $result = (string)$element;
            } else {
                // value has zero key element
                $result[0] = (string)$element;
            }
        }

        return $result;
    }

    /**
     * Check whether element has children
     *
     * @param \SimpleXMLElement $element
     * @return bool
     */
    public function hasChildren(\SimpleXMLElement $element)
    {
        if (!$element->children()) {
            return false;
        }
        // simplexml bug: @attributes is in children() but invisible in foreach
        foreach ($element->children() as $child) {
            return true;
        }

        return false;
    }
}
